@@ -1,5 +1,5 @@
 (* libguestfs
- * Copyright (C) 2009-2019 Red Hat Inc.
+ * Copyright (C) 2009-2020 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -111,6 +111,10 @@ and generate_ruby_c actions () =
   pr "\
 #include <config.h>
 
+/* It is safe to call deprecated functions from this file. */
+#define GUESTFS_NO_WARN_DEPRECATED
+#undef GUESTFS_NO_DEPRECATED
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -249,6 +253,16 @@ and generate_ruby_c actions () =
         pr "\n"
       );
 
+      (match f.deprecated_by with
+      | Not_deprecated -> ()
+      | Replaced_by alt ->
+        pr "  rb_warn (\"Guestfs#%s is deprecated; use #%s instead\");\n" f.name alt;
+        pr "\n"
+      | Deprecated_no_replacement ->
+        pr "  rb_warn (\"Guestfs#%s is deprecated\");\n" f.name;
+        pr "\n"
+      );
+
       List.iter (
         function
         | String (_, n) ->
